@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2016-01-23'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2016-02-05'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict;
@@ -108,8 +108,6 @@ sub _parse_command_line {
 
 # return ($err, $res, $decoded_val)
 sub _parse_raw_value {
-    no warnings; # XXX no warnings 'experimental::smartmatch', but this is unrecognized in 5.10
-
     my ($self, $val, $needs_res) = @_;
 
     if ($val =~ /\A!/ && $self->{enable_encoding}) {
@@ -125,12 +123,12 @@ sub _parse_raw_value {
         if ($self->{allow_encodings}) {
             return ("Encoding '$enc' is not in ".
                         "allow_encodings list")
-                unless $enc ~~ @{$self->{allow_encodings}};
+                unless grep {$_ eq $enc} @{$self->{allow_encodings}};
         }
         if ($self->{disallow_encodings}) {
             return ("Encoding '$enc' is in ".
                         "disallow_encodings list")
-                if $enc ~~ @{$self->{disallow_encodings}};
+                if grep {$_ eq $enc} @{$self->{disallow_encodings}};
         }
 
         if ($enc eq 'json') {
@@ -394,7 +392,7 @@ sub _read_file {
         or die "Can't open file '$filename': $!";
     binmode($fh, ":utf8");
     local $/;
-    return ~~<$fh>;
+    return scalar <$fh>;
 }
 
 sub read_file {
@@ -430,7 +428,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.20 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-01-23.
+This document describes version 0.21 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-02-05.
 
 =head1 EXPRESSION
 
@@ -629,7 +627,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Config-IOD-Reader>.
+Source repository is at L<https://github.com/perlancar/perl-Config-IOD-Reader>.
 
 =head1 BUGS
 
